AOS.init();
// Initialize a new Lenis instance for smooth scrolling
const lenis = new Lenis();

// Synchronize Lenis scrolling with GSAP's ScrollTrigger plugin
lenis.on('scroll', ScrollTrigger.update);

// Add Lenis's requestAnimationFrame (raf) method to GSAP's ticker
// This ensures Lenis's smooth scroll animation updates on each GSAP tick
gsap.ticker.add((time) => {
    lenis.raf(time * 1000); // Convert time from seconds to milliseconds
});

// Disable lag smoothing in GSAP to prevent any delay in scroll animations
gsap.ticker.lagSmoothing(0);

document.getElementById('toggleButton').addEventListener('click', function () {
    this.classList.toggle('toggler-active');
});

window.onbeforeunload = function () {
    window.scrollTo(0, 0);
};

const texts = [
    "WRITER",
    "CODER",
    "ARTIST",
    "ACHIEVER",
    "RESEARCHER",
    "CREATOR",
    "HUSTLER",
    "CHAMPION",
    "INNOVATOR",
    "GENIUS",
    "NAVIGATOR",
    "PERFORMER",
    "GO-GETTER",
    "RISING STAR",
    "ASPIRANT",
    "LEARNER"
];

let currentIndex = 0;
const changeTextElement = document.getElementById('changeText');
const loopTime = 170; // Fast text change time
const pauseTime = 700; // Time to pause on "LEARNER"
let isAnimating = false; // Flag to prevent multiple animations

// GSAP timeline
const tl = gsap.timeline({ paused: true });

tl.to("#wordFor", { opacity: 1, duration: 0.1 })
    .to("#wordThe", { opacity: 1, duration: 0.1 }, "+=0.2") // Show "The"
    .call(() => {
        // Add a longer delay before showing the first word (WRITER)
    }, "+=0.2") // Add 0.5 seconds delay after "The"
    .call(() => {
        // Show the text changing section statically, before "In"
        document.getElementById('changeText').style.display = 'inline-block';
        document.getElementById('changeText').textContent = texts[0]; // Set first text static (WRITER)
    })
    .to("#changeText", { opacity: 1, duration: 0.3 }) // Brief delay and show static text
    .to("#wordIn", { opacity: 1, duration: 0.1 }, "+=0.2") // After text section, show "In"
    .to("#wordYou", { opacity: 1, duration: 0.1 }, "+=0.2") // Show "You"
    .call(() => {
        startAnimationOnce(); // Start the text change animation after "You"
    });

// Text changing function
function updateText() {
    changeTextElement.textContent = texts[currentIndex];
    currentIndex++;
}

// Recursive function to handle different timing, runs through texts only once
function startAnimationOnce() {
    if (isAnimating) return; // Prevent starting the animation again if it's already running
    isAnimating = true; // Set the flag to true

    function loop() {
        updateText();

        // Stop the loop once the last text has been displayed
        if (currentIndex >= texts.length) {
            isAnimating = false; // Animation done, allow for future use if needed
            return; // Exit the loop, animation is done
        }

        // If the current text is "LEARNER", pause for longer
        const delay = texts[currentIndex - 1] === "LEARNER" ? pauseTime : loopTime;

        setTimeout(() => {
            loop(); // Continue the loop after the appropriate delay
        }, delay);
    }

    loop(); // Start the loop
}

// Intersection Observer to detect when the animationContainer div enters the viewport
const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
        if (entry.isIntersecting) {
            // Add a 200ms delay before starting the GSAP timeline
            setTimeout(() => {
                tl.play(); // Start the GSAP timeline after the brief delay
            }, 200);

            observer.unobserve(entry.target); // Stop observing after the animation starts
        }
    });
});

observer.observe(document.getElementById('animationContainer'));

// Tab section
document.addEventListener("DOMContentLoaded", function () {
    const desktopButtons = document.querySelectorAll('.meet-btn');
    const mobileButtons = document.querySelectorAll('.mobile-tab');
    const videos = document.querySelectorAll('.tab-content video');
    const tabContents = document.querySelectorAll('.tab-content');
    let currentIndex = 0;
    let firstVideoTriggered = false; // Flag to track if the first video has been triggered by the observer

    // Function to reset all tabs and descriptions
    function resetTabs() {
        document.querySelectorAll('.tab-content').forEach(tab => {
            tab.style.display = 'none';
            const video = tab.querySelector('video');
            if (video) {
                video.pause();
                video.currentTime = 0; // Reset video time to 0
            }
        });
        document.querySelectorAll('.desc-content').forEach(desc => {
            desc.style.display = 'none';
        });
    }

    // Function to play the video and toggle tabs at the given index
    function playVideoAtIndex(index) {
        resetTabs();

        // Update active state for desktop buttons
        desktopButtons.forEach(btn => btn.classList.remove('active'));
        desktopButtons[index].classList.add('active');

        // Update active state for mobile buttons
        mobileButtons.forEach(btn => btn.classList.remove('active'));
        mobileButtons[index].classList.add('active');

        // Show the corresponding video and description
        const activeTab = document.querySelector(`.tab-content.tab${index + 1}`);
        if (activeTab) {
            activeTab.style.display = 'block';
            const video = activeTab.querySelector('video');
            if (video) {
                video.play();
                video.onended = () => {
                    currentIndex = (index + 1) % desktopButtons.length; // Loop to the next video and tab
                    playVideoAtIndex(currentIndex);
                };
            }
        }

        const activeDesc = document.querySelector(`.desc-content.tab${index + 1}`);
        if (activeDesc) {
            activeDesc.style.display = 'block';
        }
    }

    // Intersection Observer to trigger the first video play when it comes into view
    const observer = new IntersectionObserver((entries) => {
        entries.forEach(entry => {
            if (entry.isIntersecting && !firstVideoTriggered) {
                playVideoAtIndex(0); // Play the first video when it comes into view
                firstVideoTriggered = true; // Mark the first video as triggered
                observer.disconnect(); // Disconnect the observer after the first video starts
                window.removeEventListener('scroll', scrollHandler); // Remove the scroll event handler
            }
        });
    }, { threshold: 0.5 }); // Play when 50% of the first video section is visible

    // Observe the first tab content to trigger the first video
    const firstTab = document.querySelector('.tab-content.tab1'); // Assuming the first tab is the first one
    observer.observe(firstTab);

    // Scroll event handler to continue playing videos after the first one
    function scrollHandler() {
        if (firstVideoTriggered) {
            tabContents.forEach((tab, index) => {
                if (isInView(tab) && currentIndex !== index) {
                    currentIndex = index; // Update current index to the tab in view
                    playVideoAtIndex(currentIndex);
                }
            });
        }
    }

    // Add the scroll event listener
    window.addEventListener('scroll', scrollHandler);

    // Function to check if the tab is in view
    function isInView(element) {
        const rect = element.getBoundingClientRect();
        return (
            rect.top >= 0 &&
            rect.left >= 0 &&
            rect.bottom <= (window.innerHeight || document.documentElement.clientHeight) &&
            rect.right <= (window.innerWidth || document.documentElement.clientWidth)
        );
    }

    // Add event listeners to desktop buttons
    desktopButtons.forEach((button, index) => {
        button.addEventListener('click', function () {
            currentIndex = index; // Update the current index to the clicked button's index
            playVideoAtIndex(currentIndex);
        });
    });

    // Add event listeners to mobile buttons
    mobileButtons.forEach((button, index) => {
        button.addEventListener('click', function () {
            currentIndex = index; // Update the current index to the clicked button's index
            playVideoAtIndex(currentIndex);
        });
    });

    // Progress bar update logic
    videos.forEach((video, index) => {
        video.addEventListener('timeupdate', () => {
            updateProgress(index, video);
        });
    });

    // Function to update the progress bar
    function updateProgress(index, video) {
        const progress = (video.currentTime / video.duration) * 100;
        desktopButtons[index].style.setProperty('--progress-width', progress + '%');
        mobileButtons[index].style.setProperty('--progress-width', progress + '%');
    }
});


// for mobile tab section

document.addEventListener('DOMContentLoaded', () => {
    const swiper = new Swiper('#mobileTab', {
        loop: true,
        autoplay: false,
        pagination: {
            el: '.swiper-pagination-custom',
            clickable: true,
            bulletClass: 'swiper-pagination-bullet',
            bulletActiveClass: 'swiper-pagination-bullet-active',
        },
        navigation: {
            nextEl: '.mob-next',
            prevEl: '.mob-prev',
        },
        breakpoints: {
            768: { slidesPerView: 3, slidesPerGroup: 1 },
            640: { slidesPerView: 2, slidesPerGroup: 2 },
            320: { slidesPerView: 1.5 },
        },
    });

    let progressInterval; // Declare interval variable outside for reuse

    // Function to handle the video ending and move to the next slide
    function handleVideoEnd() {
        swiper.slideNext(); // Move to the next slide when a video ends
    }

    // Get all video elements within the tab-content class
    const videos = document.querySelectorAll('.tab-content video');

    // Add an event listener for each video to trigger when it ends
    videos.forEach(video => {
        video.addEventListener('ended', handleVideoEnd);
    });

    // Function to update the active class on mobile-tab buttons and show the corresponding video
    function updateActiveTab() {
        // Find the index of the currently active slide
        const activeIndex = swiper.realIndex;

        // Remove active class from all mobile-tab buttons
        const allButtons = document.querySelectorAll('.mobile-tab');
        allButtons.forEach(button => {
            button.classList.remove('active');
        });

        // Hide all tab-content elements (videos)
        const allContents = document.querySelectorAll('.tab-content');
        allContents.forEach(content => {
            content.style.display = 'none';
        });

        // Find the button corresponding to the active slide and add the active class
        const activeButton = document.querySelector(`.swiper-slide[data-swiper-slide-index="${activeIndex}"] .mobile-tab`);
        if (activeButton) {
            activeButton.classList.add('active');
        }

        // Show and play the video corresponding to the active tab
        const activeContent = document.querySelector(`.tab-content[data-target="tab${activeIndex + 1}"]`);
        if (activeContent) {
            activeContent.style.display = 'block';
            const video = activeContent.querySelector('video');
            if (video) {
                // Pause all other videos
                videos.forEach(v => {
                    if (v !== video) {
                        v.pause();
                        v.currentTime = 0; // Reset time for all other videos
                    }
                });

                video.play().catch(error => {
                    console.warn('Video play was interrupted:', error);
                });

                // Update video progress for the corresponding pagination bullet
                updateVideoProgress(video, activeIndex); // Call update for the new video
            }
        }

        // Update the active dot based on the active index
        updateProgressDots(activeIndex);
    }

    function updateProgressDots(activeIndex) {
        // Remove active-dot class from all dots and reset progress bars
        document.querySelectorAll('.custom-dot').forEach((dot, index) => {
            dot.classList.remove('active-dot');
            const progressBar = dot.querySelector('.progress-bar');
            if (progressBar) {
                progressBar.style.width = '0%'; // Reset progress bar
            }

            // Ensure the active dot is set correctly
            if (index === activeIndex) {
                dot.classList.add('active-dot'); // Add active class
            }
        });
    }

    function updateVideoProgress(video, index) {
        // Clear any existing progress interval to avoid multiple intervals running
        clearInterval(progressInterval);

        // Get the progress bar element inside the active dot
        const activeDot = document.querySelectorAll('.custom-dot')[index];
        const progressBar = activeDot.querySelector('.progress-bar');

        if (progressBar) {
            // Update the progress bar width as the video plays
            progressInterval = setInterval(() => {
                if (video.duration) {
                    const progressPercentage = (video.currentTime / video.duration) * 100;
                    progressBar.style.width = `${progressPercentage}%`; // Set progress width

                    // Stop the interval when the video ends or reaches 100%
                    if (video.ended || progressPercentage >= 100) {
                        clearInterval(progressInterval); // Clear interval when done
                        progressBar.style.width = '0%'; // Reset progress bar when done
                    }
                }
            }, 100); // Update every 100ms for smooth progress
        }
    }

    // Ensure the correct video plays and active tab is updated when the slide changes
    swiper.on('slideChange', updateActiveTab);

    // Play the video of the initial active slide and set the initial active class
    const initialVideo = document.querySelector('.tab-content[data-target="tab1"] video');
    if (initialVideo) {
        initialVideo.play().catch(error => {
            console.warn('Initial video play was interrupted:', error);
        });
    }

    updateActiveTab(); // Set the active class for the first time
});







// First Swiper Slider
document.addEventListener("DOMContentLoaded", function () {
    const swiperFirst = new Swiper('#firstSlider', {
        loop: false,
        slidesPerView: 4,
        spaceBetween: 0,
        navigation: {
            nextEl: '.desktop-next-btn',
            prevEl: '.desktop-prev-btn',
        },
        speed: 500, // Adjust the speed of transitions
        breakpoints: {
            1024: {
                slidesPerView: 4,

            },
            768: {
                slidesPerView: 3,

            },
            640: {
                slidesPerView: 2,
            },
            320: {
                slidesPerView: 1.5,
            }
        }
    });
});

document.addEventListener("DOMContentLoaded", function () {
    const swiperSecond = new Swiper('.swiper-container-second', {
        loop: false,
        spaceBetween: 20,
        roundLengths: true, // Ensure fractional slides are calculated properly
        navigation: {
            nextEl: '.swiper-button-next-second', // Unique button class
            prevEl: '.swiper-button-prev-second', // Unique button class
        },
        speed: 600,
        slidesPerView: 4.75,
        slidesPerGroup: 1, // Move one slide at a time
        centeredSlides: false,
        spaceBetween: 10,
        watchSlidesProgress: true,
        breakpoints: {
            1024: {
                slidesPerView: 4.75,
                spaceBetween: 10,
            },
            768: {
                slidesPerView: 3.5,
                spaceBetween: 10,
            },
            640: {
                slidesPerView: 1.5,
                spaceBetween: 10,
            },
            320: {
                slidesPerView: 1.2,
                spaceBetween: 10,
            }
        },
        on: {
            reachEnd: function () {
                const totalSlides = swiperSecond.slides.length;
                const slidesInView = Math.floor(swiperSecond.slidesPerView); // Full slides visible
                const remainingSlides = totalSlides - swiperSecond.activeIndex;

                // Adjust to show last slide fully if it's about to be cut off
                if (remainingSlides < slidesInView) {
                    swiperSecond.slidesPerView = remainingSlides;
                }
            }
        }
    });
});


// accordian image 

document.addEventListener('DOMContentLoaded', function () {
    const accordionButtons = document.querySelectorAll('#accordionExample .accordion-button');
    const imageElement = document.getElementById('accordionImage');

    accordionButtons.forEach(button => {
        button.addEventListener('click', function (e) {
            // Get the target collapse element
            const targetCollapse = this.getAttribute('data-bs-target');
            const collapseElement = document.querySelector(targetCollapse);

            // If the clicked accordion is already open, prevent further action
            if (collapseElement.classList.contains('show')) {
                e.preventDefault(); // Prevent the accordion from closing and reopening
                return;
            }

            // Close all other accordions
            accordionButtons.forEach(otherButton => {
                const otherCollapse = document.querySelector(otherButton.getAttribute('data-bs-target'));
                if (otherCollapse !== collapseElement && otherCollapse.classList.contains('show')) {
                    // Manually hide other opened accordions
                    otherCollapse.classList.remove('show');
                    otherButton.classList.add('collapsed');
                    otherButton.setAttribute('aria-expanded', 'false');
                }
            });

            // Set the image for the current accordion
            const imagePath = this.getAttribute('data-image');
            if (imagePath && imageElement) {
                imageElement.setAttribute('src', imagePath);
            }
        });
    });
});


document.addEventListener("DOMContentLoaded", function () {
    const swiper1 = new Swiper('.row-1', {
        slidesPerView: 1.5, // Show 5.5 slides on large screens
        spaceBetween: 30, // Space between slides
        // loop: true, // Enable loop mode
        autoplay: {
            delay: 3000, // Delay between transitions in ms
            disableOnInteraction: false, // Autoplay won't be disabled after user interaction
        },
        breakpoints: {
            768: { // Mobile view
                slidesPerView: 3.5, // Show 1.5 slides on screens up to 768px wide
                spaceBetween: 20, // Adjust space between slides for mobile if needed
            },
            1024: { // Tablet and larger view
                slidesPerView: 4.5, // Show 5.5 slides on larger screens
                spaceBetween: 25, // Adjust space between slides for larger screens if needed
            },
        },
    });

    const swiper2 = new Swiper('.row-2', {
        slidesPerView: 1.5,
        spaceBetween: 30,
        // loop: true,
        autoplay: {
            delay: 3000,
            reverseDirection: true,
            disableOnInteraction: false,
        },
        breakpoints: {
            768: {
                slidesPerView: 3.5,
                spaceBetween: 20,
            },
            1024: {
                slidesPerView: 4.5,
                spaceBetween: 25,
            },
        },
    });
});


function openCity(evt, cityName) {
    // Declare all variables
    var i, tabcontent, tablinks;

    // Get all elements with class="tabcontent" and hide them
    tabcontent = document.getElementsByClassName("tabcontent");
    for (i = 0; i < tabcontent.length; i++) {
        tabcontent[i].style.display = "none";
    }

    // Get all elements with class="tablinks" and remove the class "active"
    tablinks = document.getElementsByClassName("tablinks");
    for (i = 0; i < tablinks.length; i++) {
        tablinks[i].classList.remove("active");
    }

    // Show the current tab, and add an "active" class to the button that opened the tab
    document.getElementById(cityName).style.display = "block";
    evt.currentTarget.classList.add("active");
}



