// Initialize a new Lenis instance for smooth scrolling with mobile-specific adjustments
const lenis = new Lenis({
  smooth: true,
  smoothTouch: true,                   // Enable smooth touch behavior for mobile
  lerp: window.innerWidth < 768 ? 0.08 : 0.1, // Lower lerp for mobile to create resistance for fast swipes
  touchMultiplier: window.innerWidth < 768 ? 0.5 : 1 // Decrease touch responsiveness on mobile only
});

// Synchronize Lenis scrolling with GSAP's ScrollTrigger plugin
lenis.on('scroll', ScrollTrigger.update);

// Add Lenis's requestAnimationFrame (raf) method to GSAP's ticker
// This ensures Lenis's smooth scroll animation updates on each GSAP tick
gsap.ticker.add((time) => {
    lenis.raf(time * 1000); // Convert time from seconds to milliseconds
});

// Disable lag smoothing in GSAP to prevent any delay in scroll animations
gsap.ticker.lagSmoothing(0);

// Optional: Update settings on resize to maintain responsiveness
window.addEventListener('resize', () => {
  if (window.innerWidth < 768) {
    lenis.lerp = 0.08;           // Stronger resistance for mobile
    lenis.touchMultiplier = 0.5; // Slower response to touch swipes
  } else {
    lenis.lerp = 0.2;            // Original lerp for desktop
    lenis.touchMultiplier = 1;   // Standard response for desktop
  }
});



document.getElementById('toggleButton').addEventListener('click', function () {
    this.classList.toggle('toggler-active');
});

window.onbeforeunload = function () {
    window.scrollTo(0, 0);
};

const texts = [
    "WRITER",
    "CODER",
    "ARTIST",
    "ACHIEVER",
    "RESEARCHER",
    "CREATOR",
    "HUSTLER",
    "CHAMPION",
    "INNOVATOR",
    "GENIUS",
    "NAVIGATOR",
    "PERFORMER",
    "GO-GETTER",
    "RISING STAR",
    "ASPIRANT",
    "LEARNER"
];

let currentIndex = 0;
const changeTextElement = document.getElementById('changeText');
const loopTime = 170; // Fast text change time
const pauseTime = 700; // Time to pause on "LEARNER"
let isAnimating = false; // Flag to prevent multiple animations

// GSAP timeline
const tl = gsap.timeline({ paused: true });

tl.to("#wordFor", { opacity: 1, duration: 0.1 })
    .to("#wordThe", { opacity: 1, duration: 0.1 }, "+=0.2") // Show "The"
    .call(() => {
        // Add a longer delay before showing the first word (WRITER)
    }, "+=0.2") // Add 0.5 seconds delay after "The"
    .call(() => {
        // Show the text changing section statically, before "In"
        document.getElementById('changeText').style.display = 'inline-block';
        document.getElementById('changeText').textContent = texts[0]; // Set first text static (WRITER)
    })
    .to("#changeText", { opacity: 1, duration: 0.3 }) // Brief delay and show static text
    .to("#wordIn", { opacity: 1, duration: 0.1 }, "+=0.2") // After text section, show "In"
    .to("#wordYou", { opacity: 1, duration: 0.1 }, "+=0.2") // Show "You"
    .call(() => {
        startAnimationOnce(); // Start the text change animation after "You"
    });

// Text changing function
function updateText() {
    changeTextElement.textContent = texts[currentIndex];
    currentIndex++;
}

// Recursive function to handle different timing, runs through texts only once
function startAnimationOnce() {
    if (isAnimating) return; // Prevent starting the animation again if it's already running
    isAnimating = true; // Set the flag to true

    function loop() {
        updateText();

        // Stop the loop once the last text has been displayed
        if (currentIndex >= texts.length) {
            isAnimating = false; // Animation done, allow for future use if needed
            return; // Exit the loop, animation is done
        }

        // If the current text is "LEARNER", pause for longer
        const delay = texts[currentIndex - 1] === "LEARNER" ? pauseTime : loopTime;

        setTimeout(() => {
            loop(); // Continue the loop after the appropriate delay
        }, delay);
    }

    loop(); // Start the loop
}

// Intersection Observer to detect when the animationContainer div enters the viewport
const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
        if (entry.isIntersecting) {
            // Add a 200ms delay before starting the GSAP timeline
            setTimeout(() => {
                tl.play(); // Start the GSAP timeline after the brief delay
            }, 200);

            observer.unobserve(entry.target); // Stop observing after the animation starts
        }
    });
});

observer.observe(document.getElementById('animationContainer'));

// Tab section for Desktop
document.addEventListener("DOMContentLoaded", function () {
    if (window.innerWidth >= 1024) { // Desktop-specific logic
        const desktopButtons = document.querySelectorAll('.meet-btn');
        const videos = document.querySelectorAll('.tab-content video');
        const tabContents = document.querySelectorAll('.tab-content');
        let currentIndex = 0;
        let firstVideoTriggered = false;

        // Function to reset all tabs and descriptions
        function resetTabs() {
            tabContents.forEach(tab => {
                tab.style.display = 'none';
                const video = tab.querySelector('video');
                if (video) {
                    video.pause();
                    video.currentTime = 0;
                }
            });
            document.querySelectorAll('.desc-content').forEach(desc => {
                desc.style.display = 'none';
            });
        }

        // Function to play the video and toggle tabs at the given index for Desktop
        function playVideoAtIndex(index) {
            resetTabs();

            desktopButtons.forEach(btn => btn.classList.remove('active'));
            desktopButtons[index].classList.add('active');

            const activeTab = document.querySelector(`.tab-content.tab${index + 1}`);
            if (activeTab) {
                activeTab.style.display = 'block';
                const video = activeTab.querySelector('video');
                if (video) {
                    video.play();
                    video.onended = () => {
                        currentIndex = (index + 1) % desktopButtons.length;
                        playVideoAtIndex(currentIndex);
                    };
                }
            }

            const activeDesc = document.querySelector(`.desc-content.tab${index + 1}`);
            if (activeDesc) {
                activeDesc.style.display = 'block';
            }
        }

        // Intersection Observer to trigger the first video play when it comes into view
        const observer = new IntersectionObserver((entries) => {
            entries.forEach(entry => {
                if (entry.isIntersecting && !firstVideoTriggered) {
                    playVideoAtIndex(0);
                    firstVideoTriggered = true;
                    observer.disconnect();
                    window.removeEventListener('scroll', scrollHandler);
                }
            });
        }, { threshold: 0.5 });

        const firstTab = document.querySelector('.tab-content.tab1');
        observer.observe(firstTab);

        // Scroll event handler for Desktop
        function scrollHandler() {
            if (firstVideoTriggered) {
                tabContents.forEach((tab, index) => {
                    if (isInView(tab) && currentIndex !== index) {
                        currentIndex = index;
                        playVideoAtIndex(currentIndex);
                    }
                });
            }
        }

        window.addEventListener('scroll', scrollHandler);

        function isInView(element) {
            const rect = element.getBoundingClientRect();
            return (
                rect.top >= 0 &&
                rect.left >= 0 &&
                rect.bottom <= (window.innerHeight || document.documentElement.clientHeight) &&
                rect.right <= (window.innerWidth || document.documentElement.clientWidth)
            );
        }

        desktopButtons.forEach((button, index) => {
            button.addEventListener('click', function () {
                currentIndex = index;
                playVideoAtIndex(currentIndex);
            });
        });

        // Progress bar update logic
        videos.forEach((video, index) => {
            video.addEventListener('timeupdate', () => {
                updateProgress(index, video);
            });
        });

        function updateProgress(index, video) {
            const progress = (video.currentTime / video.duration) * 100;
            desktopButtons[index].style.setProperty('--progress-width', progress + '%');
        }
    }
});

// Mobile Tab Section
document.addEventListener('DOMContentLoaded', () => {
    if (window.innerWidth < 1024) { // Mobile and medium device-specific logic (up to 1024px)
        const swiper = new Swiper('#mobileTab', {
            loop: true,
            autoplay: false,
            pagination: {
                el: '.swiper-pagination-custom',
                clickable: true,
                bulletClass: 'swiper-pagination-bullet',
                bulletActiveClass: 'swiper-pagination-bullet-active',
            },
            navigation: {
                nextEl: '.mob-next',
                prevEl: '.mob-prev',
            },
            breakpoints: {
                768: { slidesPerView: 3, slidesPerGroup: 1 },
                640: { slidesPerView: 2, slidesPerGroup: 2 },
                320: { slidesPerView: 1.5 },
            },
        });

        let progressInterval;
        const videos = document.querySelectorAll('.tab-content video');

        function handleVideoEnd() {
            swiper.slideNext();
        }

        videos.forEach(video => {
            video.addEventListener('ended', handleVideoEnd);
        });

        function updateActiveTab() {
            const activeIndex = swiper.realIndex;

            const allButtons = document.querySelectorAll('.mobile-tab');
            allButtons.forEach(button => button.classList.remove('active'));

            const allContents = document.querySelectorAll('.tab-content');
            allContents.forEach(content => content.style.display = 'none');

            const activeButton = document.querySelector(`.swiper-slide[data-swiper-slide-index="${activeIndex}"] .mobile-tab`);
            if (activeButton) activeButton.classList.add('active');

            const activeContent = document.querySelector(`.tab-content[data-target="tab${activeIndex + 1}"]`);
            if (activeContent) {
                activeContent.style.display = 'block';
                const video = activeContent.querySelector('video');
                if (video) {
                    videos.forEach(v => {
                        if (v !== video) {
                            v.pause();
                            v.currentTime = 0;
                        }
                    });
                    video.play().catch(error => {
                        console.warn('Video play was interrupted:', error);
                    });
                    updateVideoProgress(video, activeIndex);
                }
            }

            updateProgressDots(activeIndex);
        }

        function updateProgressDots(activeIndex) {
            document.querySelectorAll('.custom-dot').forEach((dot, index) => {
                dot.classList.remove('active-dot');
                const progressBar = dot.querySelector('.progress-bar');
                if (progressBar) {
                    progressBar.style.width = '0%';
                }

                if (index === activeIndex) {
                    dot.classList.add('active-dot');
                }
            });
        }

        function updateVideoProgress(video, index) {
            clearInterval(progressInterval);

            const activeDot = document.querySelectorAll('.custom-dot')[index];
            const progressBar = activeDot.querySelector('.progress-bar');

            if (progressBar) {
                progressInterval = setInterval(() => {
                    if (video.duration) {
                        const progressPercentage = (video.currentTime / video.duration) * 100;
                        progressBar.style.width = `${progressPercentage}%`;

                        if (video.ended || progressPercentage >= 100) {
                            clearInterval(progressInterval);
                            progressBar.style.width = '0%';
                        }
                    }
                }, 100);
            }
        }

        // Handle click on tab buttons
        document.querySelectorAll('.mobile-tab').forEach((button, index) => {
            button.addEventListener('click', () => {
                swiper.slideToLoop(index); // Update the Swiper slide based on the clicked button
                updateActiveTab(); // Update the active tab
            });
        });

        swiper.on('slideChange', updateActiveTab);

        const initialVideo = document.querySelector('.tab-content[data-target="tab1"] video');
        if (initialVideo) {
            initialVideo.play().catch(error => {
                console.warn('Initial video play was interrupted:', error);
            });
        }

        updateActiveTab();
    }
});



// First Swiper Slider
document.addEventListener("DOMContentLoaded", function () {
    const swiperFirst = new Swiper('#firstSlider', {
        loop: false,
        slidesPerView: 4,
        spaceBetween: 0,
        navigation: {
            nextEl: '.desktop-next-btn',
            prevEl: '.desktop-prev-btn',
        },
        speed: 500, // Adjust the speed of transitions
        breakpoints: {
            1024: {
                slidesPerView: 4,

            },
            768: {
                slidesPerView: 3,

            },
            640: {
                slidesPerView: 2,
            },
            320: {
                slidesPerView: 1.5,
            }
        }
    });
});

document.addEventListener("DOMContentLoaded", function () {
    const swiperSecond = new Swiper('.swiper-container-second', {
        loop: false,
        spaceBetween: 20,
        roundLengths: true, // Ensure fractional slides are calculated properly
        navigation: {
            nextEl: '.swiper-button-next-second', // Unique button class
            prevEl: '.swiper-button-prev-second', // Unique button class
        },
        speed: 600,
        slidesPerView: 4.75,
        slidesPerGroup: 1, // Move one slide at a time
        centeredSlides: false,
        spaceBetween: 10,
        watchSlidesProgress: true,
        breakpoints: {
            1024: {
                slidesPerView: 4.75,
                spaceBetween: 10,
            },
            768: {
                slidesPerView: 3.5,
                spaceBetween: 10,
            },
            640: {
                slidesPerView: 1.5,
                spaceBetween: 10,
            },
            320: {
                slidesPerView: 1.5,
                spaceBetween: 10,
            }
        },
        on: {
            reachEnd: function () {
                const totalSlides = swiperSecond.slides.length;
                const slidesInView = Math.floor(swiperSecond.slidesPerView); // Full slides visible
                const remainingSlides = totalSlides - swiperSecond.activeIndex;

                // Adjust to show last slide fully if it's about to be cut off
                if (remainingSlides < slidesInView) {
                    swiperSecond.slidesPerView = remainingSlides;
                }
            }
        }
    });
});


// accordian image 

document.addEventListener('DOMContentLoaded', function () {
    const accordionButtons = document.querySelectorAll('#accordionExample .accordion-button');
    const imageElement = document.getElementById('accordionImage');

    accordionButtons.forEach(button => {
        button.addEventListener('click', function (e) {
            // Get the target collapse element
            const targetCollapse = this.getAttribute('data-bs-target');
            const collapseElement = document.querySelector(targetCollapse);

            // If the clicked accordion is already open, prevent further action
            if (collapseElement.classList.contains('show')) {
                e.preventDefault(); // Prevent the accordion from closing and reopening
                return;
            }

            // Close all other accordions
            accordionButtons.forEach(otherButton => {
                const otherCollapse = document.querySelector(otherButton.getAttribute('data-bs-target'));
                if (otherCollapse !== collapseElement && otherCollapse.classList.contains('show')) {
                    // Manually hide other opened accordions
                    otherCollapse.classList.remove('show');
                    otherButton.classList.add('collapsed');
                    otherButton.setAttribute('aria-expanded', 'false');
                }
            });

            // Set the image for the current accordion
            const imagePath = this.getAttribute('data-image');
            if (imagePath && imageElement) {
                imageElement.setAttribute('src', imagePath);
            }
        });
    });
});


document.addEventListener("DOMContentLoaded", function () {
    // Function to determine if autoplay should be enabled
    function isAutoplayEnabled() {
        return window.innerWidth >= 768; // Enable autoplay only for screens 768px and above
    }

    const swiper1 = new Swiper('.row-1', {
        slidesPerView: 1.5,
        spaceBetween: 30,
        autoplay: isAutoplayEnabled() ? {
            delay: 3000,
            disableOnInteraction: false,
        } : false,
        breakpoints: {
            768: {
                slidesPerView: 3.5,
                spaceBetween: 20,
            },
            1024: {
                slidesPerView: 4.5,
                spaceBetween: 25,
            },
        },
    });

    const swiper2 = new Swiper('.row-2', {
        slidesPerView: 1.5,
        spaceBetween: 30,
        autoplay: isAutoplayEnabled() ? {
            delay: 3000,
            reverseDirection: true,
            disableOnInteraction: false,
        } : false,
        breakpoints: {
            768: {
                slidesPerView: 3.5,
                spaceBetween: 20,
            },
            1024: {
                slidesPerView: 4.5,
                spaceBetween: 25,
            },
        },
    });

    // Add a resize event listener to update autoplay on window resize
    window.addEventListener('resize', function () {
        const enableAutoplay = isAutoplayEnabled();
        if (enableAutoplay) {
            swiper1.autoplay.start();
            swiper2.autoplay.start();
        } else {
            swiper1.autoplay.stop();
            swiper2.autoplay.stop();
        }
    });
});



function openCity(evt, cityName) {
    // Declare all variables
    var i, tabcontent, tablinks;

    // Get all elements with class="tabcontent" and hide them
    tabcontent = document.getElementsByClassName("tabcontent");
    for (i = 0; i < tabcontent.length; i++) {
        tabcontent[i].style.display = "none";
    }

    // Get all elements with class="tablinks" and remove the class "active"
    tablinks = document.getElementsByClassName("tablinks");
    for (i = 0; i < tablinks.length; i++) {
        tablinks[i].classList.remove("active");
    }

    // Show the current tab, and add an "active" class to the button that opened the tab
    document.getElementById(cityName).style.display = "block";
    evt.currentTarget.classList.add("active");
}

document.addEventListener('DOMContentLoaded', () => {
    // Select all accordion buttons and the main accordion section container
    const accordionButtons = document.querySelectorAll('.accordion-button');
    const accordionDiv = document.getElementById('accordian_div');

    accordionButtons.forEach(button => {
        button.addEventListener('click', () => {
            // Use a timeout to let the accordion toggle first before checking visibility
            setTimeout(() => {
                // Get the bounding box of the accordion_div section
                const rect = accordionDiv.getBoundingClientRect();
                
                // Check if the section is fully in the viewport
                const isFullyVisible = rect.top >= 0 && rect.bottom <= window.innerHeight;
                
                // Scroll the accordion_div into view if it's not fully visible
                if (!isFullyVisible) {
                    accordionDiv.scrollIntoView({ behavior: 'smooth', block: 'start' });
                }
            }, 300); // Delay to allow accordion to expand/collapse
        });
    });
});


